@@ -45,7 +45,7 @@
 #include "gpm-brightness.h"
 #include "gpm-control.h"
 #include "gpm-common.h"
-#include "gsd-media-keys-window.h"
+#include "gpm-osd-dialog.h"
 #include "gpm-dpms.h"
 #include "gpm-idle.h"
 #include "gpm-marshal.h"
@@ -76,6 +76,7 @@ struct GpmBacklightPrivate
 	GpmBrightness		*brightness;
 	GpmButton		*button;
 	GSettings		*settings;
+	GSettings		*settings_gsd;
 	GtkWidget		*popup;
 	GpmControl		*control;
 	GpmDpms			*dpms;
@@ -90,13 +91,6 @@ struct GpmBacklightPrivate
 	guint			 bus_object_id;
 };
 
-enum {
-	BRIGHTNESS_CHANGED,
-	LAST_SIGNAL
-};
-
-static guint signals [LAST_SIGNAL] = { 0 };
-
 G_DEFINE_TYPE (GpmBacklight, gpm_backlight, G_TYPE_OBJECT)
 
 /**
@@ -144,6 +138,26 @@ gpm_backlight_get_brightness (GpmBacklight *backlight, guint *brightness, GError
 	return ret;
 }
 
+/**
+ * gpm_backlight_brightness_changed:
+ **/
+static void
+gpm_backlight_brightness_changed (GpmBacklight *backlight, guint percentage)
+{
+	/* save the new percentage */
+	backlight->priv->master_percentage = percentage;
+
+	/* we emit a signal for the brightness applet */
+	g_debug ("emitting brightness-changed : %i", percentage);
+	g_dbus_connection_emit_signal (backlight->priv->bus_connection,
+			NULL,
+			GPM_DBUS_PATH_BACKLIGHT,
+			GPM_DBUS_INTERFACE_BACKLIGHT,
+			"BrightnessChanged",
+			g_variant_new ("(u)", percentage),
+			NULL);
+}
+
 /**
  * gpm_backlight_set_brightness:
  **/
@@ -175,99 +189,11 @@ gpm_backlight_set_brightness (GpmBacklight *backlight, guint percentage, GError
 				      "Cannot set policy brightness");
 	}
 	/* we emit a signal for the brightness applet */
-	if (ret && hw_changed) {
-		g_debug ("emitting brightness-changed : %i", percentage);
-		g_signal_emit (backlight, signals [BRIGHTNESS_CHANGED], 0, percentage);
-	}
+	if (ret && hw_changed)
+		gpm_backlight_brightness_changed (backlight, percentage);
 	return ret;
 }
 
-/**
- * gpm_backlight_dialog_init:
- *
- * Initialises the popup, and makes sure that it matches the compositing of the screen.
- **/
-static void
-gpm_backlight_dialog_init (GpmBacklight *backlight)
-{
-	if (backlight->priv->popup != NULL
-	    && !gsd_osd_window_is_valid (GSD_OSD_WINDOW (backlight->priv->popup))) {
-		gtk_widget_destroy (backlight->priv->popup);
-		backlight->priv->popup = NULL;
-	}
-
-	if (backlight->priv->popup == NULL) {
-		backlight->priv->popup= gsd_media_keys_window_new ();
-		gsd_media_keys_window_set_action_custom (GSD_MEDIA_KEYS_WINDOW (backlight->priv->popup),
-							 "gpm-brightness-lcd",
-							 TRUE);
-		gtk_window_set_position (GTK_WINDOW (backlight->priv->popup), GTK_WIN_POS_NONE);
-	}
-}
-
-/**
- * gpm_backlight_dialog_show:
- *
- * Show the brightness popup, and place it nicely on the screen.
- **/
-static void
-gpm_backlight_dialog_show (GpmBacklight *backlight)
-{
-	int            orig_w;
-	int            orig_h;
-	int            screen_w;
-	int            screen_h;
-	int            x;
-	int            y;
-	int            pointer_x;
-	int            pointer_y;
-	GtkRequisition win_req;
-	GdkScreen     *pointer_screen;
-	GdkRectangle   geometry;
-	int            monitor;
-
-	/*
-	 * get the window size
-	 * if the window hasn't been mapped, it doesn't necessarily
-	 * know its true size, yet, so we need to jump through hoops
-	 */
-	gtk_window_get_default_size (GTK_WINDOW (backlight->priv->popup), &orig_w, &orig_h);
-	gtk_widget_get_preferred_size(backlight->priv->popup, &win_req, NULL);
-
-	if (win_req.width > orig_w) {
-		orig_w = win_req.width;
-	}
-	if (win_req.height > orig_h) {
-		orig_h = win_req.height;
-	}
-
-	pointer_screen = NULL;
-	gdk_display_get_pointer (gtk_widget_get_display (backlight->priv->popup),
-				 &pointer_screen,
-				 &pointer_x,
-				 &pointer_y,
-				 NULL);
-	monitor = gdk_screen_get_monitor_at_point (pointer_screen,
-						   pointer_x,
-						   pointer_y);
-
-	gdk_screen_get_monitor_geometry (pointer_screen,
-					 monitor,
-					 &geometry);
-
-	screen_w = geometry.width;
-	screen_h = geometry.height;
-
-	x = ((screen_w - orig_w) / 2) + geometry.x;
-	y = geometry.y + (screen_h / 2) + (screen_h / 2 - orig_h) / 2;
-
-	gtk_window_move (GTK_WINDOW (backlight->priv->popup), x, y);
-
-	gtk_widget_show (backlight->priv->popup);
-
-	gdk_display_sync (gtk_widget_get_display (backlight->priv->popup));
-}
-
 /**
  * gpm_common_sum_scale:
  *
@@ -335,11 +261,11 @@ gpm_backlight_brightness_evaluate_and_set (GpmBacklight *backlight, gboolean int
 
 	/* reduce if system is momentarily idle */
 	if (!on_battery)
-		enable_action = g_settings_get_boolean (backlight->priv->settings, GPM_SETTINGS_IDLE_DIM_AC);
+		enable_action = g_settings_get_boolean (backlight->priv->settings_gsd, GSD_SETTINGS_IDLE_DIM_AC);
 	else
-		enable_action = g_settings_get_boolean (backlight->priv->settings, GPM_SETTINGS_IDLE_DIM_BATT);
+		enable_action = g_settings_get_boolean (backlight->priv->settings_gsd, GSD_SETTINGS_IDLE_DIM_BATT);
 	if (enable_action && backlight->priv->system_is_idle) {
-		value = g_settings_get_int (backlight->priv->settings, GPM_SETTINGS_IDLE_BRIGHTNESS);
+		value = g_settings_get_int (backlight->priv->settings_gsd, GSD_SETTINGS_IDLE_BRIGHTNESS);
 		if (value > 100) {
 			g_warning ("cannot use idle brightness value %i, correcting to 50", value);
 			value = 50;
@@ -363,18 +289,16 @@ gpm_backlight_brightness_evaluate_and_set (GpmBacklight *backlight, gboolean int
 
 	/* only show dialog if interactive */
 	if (interactive) {
-		gpm_backlight_dialog_init (backlight);
+		gpm_osd_dialog_init (&backlight->priv->popup, "display-brightness-symbolic");
 		gsd_media_keys_window_set_volume_level (GSD_MEDIA_KEYS_WINDOW (backlight->priv->popup),
 							round (brightness));
-		gpm_backlight_dialog_show (backlight);
+		gpm_osd_dialog_show (backlight->priv->popup);
 	}
 
 	ret = gpm_brightness_set (backlight->priv->brightness, value, &hw_changed);
 	/* we emit a signal for the brightness applet */
-	if (ret && hw_changed) {
-		g_debug ("emitting brightness-changed : %i", value);
-		g_signal_emit (backlight, signals [BRIGHTNESS_CHANGED], 0, value);
-	}
+	if (ret && hw_changed)
+		gpm_backlight_brightness_changed (backlight, value);
 	return TRUE;
 }
 
@@ -400,14 +324,14 @@ gpm_settings_key_changed_cb (GSettings *settings, const gchar *key, GpmBacklight
 	} else if (on_battery && g_strcmp0 (key, GPM_SETTINGS_BRIGHTNESS_DIM_BATT) == 0) {
 		gpm_backlight_brightness_evaluate_and_set (backlight, FALSE);
 
-	} else if (g_strcmp0 (key, GPM_SETTINGS_IDLE_DIM_AC) == 0 ||
+	} else if (g_strcmp0 (key, GSD_SETTINGS_IDLE_DIM_AC) == 0 ||
 		   g_strcmp0 (key, GPM_SETTINGS_BACKLIGHT_ENABLE) == 0 ||
-		   g_strcmp0 (key, GPM_SETTINGS_SLEEP_DISPLAY_BATT) == 0 ||
+		   g_strcmp0 (key, GSD_SETTINGS_SLEEP_DISPLAY_BATT) == 0 ||
 		   g_strcmp0 (key, GPM_SETTINGS_BACKLIGHT_BATTERY_REDUCE) == 0 ||
-		   g_strcmp0 (key, GPM_SETTINGS_IDLE_BRIGHTNESS) == 0) {
+		   g_strcmp0 (key, GSD_SETTINGS_IDLE_BRIGHTNESS) == 0) {
 		gpm_backlight_brightness_evaluate_and_set (backlight, FALSE);
 
-	} else if (g_strcmp0 (key, GPM_SETTINGS_IDLE_DIM_TIME) == 0) {
+	} else if (g_strcmp0 (key, GSD_SETTINGS_IDLE_DIM_TIME) == 0) {
 		backlight->priv->idle_dim_timeout = g_settings_get_int (settings, key);
 		gpm_idle_set_timeout_dim (backlight->priv->idle, backlight->priv->idle_dim_timeout);
 	} else {
@@ -451,18 +375,17 @@ gpm_backlight_button_pressed_cb (GpmButton *button, const gchar *type, GpmBackli
 		/* show the new value */
 		if (ret) {
 			gpm_brightness_get (backlight->priv->brightness, &percentage);
-			gpm_backlight_dialog_init (backlight);
+			gpm_osd_dialog_init (&backlight->priv->popup, "display-brightness-symbolic");
 			gsd_media_keys_window_set_volume_level (GSD_MEDIA_KEYS_WINDOW (backlight->priv->popup),
 								percentage);
-			gpm_backlight_dialog_show (backlight);
+			gpm_osd_dialog_show (backlight->priv->popup);
 			/* save the new percentage */
 			backlight->priv->master_percentage = percentage;
 		}
 		/* we emit a signal for the brightness applet */
-		if (ret && hw_changed) {
-			g_debug ("emitting brightness-changed : %i", percentage);
-			g_signal_emit (backlight, signals [BRIGHTNESS_CHANGED], 0, percentage);
-		}
+		if (ret && hw_changed)
+			gpm_backlight_brightness_changed (backlight, percentage);
+
 	} else if (g_strcmp0 (type, GPM_BUTTON_BRIGHT_DOWN) == 0) {
 		/* go up down step */
 		ret = gpm_brightness_down (backlight->priv->brightness, &hw_changed);
@@ -470,18 +393,17 @@ gpm_backlight_button_pressed_cb (GpmButton *button, const gchar *type, GpmBackli
 		/* show the new value */
 		if (ret) {
 			gpm_brightness_get (backlight->priv->brightness, &percentage);
-			gpm_backlight_dialog_init (backlight);
+			gpm_osd_dialog_init (&backlight->priv->popup, "display-brightness-symbolic");
 			gsd_media_keys_window_set_volume_level (GSD_MEDIA_KEYS_WINDOW (backlight->priv->popup),
 								percentage);
-			gpm_backlight_dialog_show (backlight);
+			gpm_osd_dialog_show (backlight->priv->popup);
 			/* save the new percentage */
 			backlight->priv->master_percentage = percentage;
 		}
 		/* we emit a signal for the brightness applet */
-		if (ret && hw_changed) {
-			g_debug ("emitting brightness-changed : %i", percentage);
-			g_signal_emit (backlight, signals [BRIGHTNESS_CHANGED], 0, percentage);
-		}
+		if (ret && hw_changed)
+			gpm_backlight_brightness_changed (backlight, percentage);
+
 	} else if (g_strcmp0 (type, GPM_BUTTON_LID_OPEN) == 0) {
 		/* make sure we undim when we lift the lid */
 		gpm_backlight_brightness_evaluate_and_set (backlight, FALSE);
@@ -530,8 +452,8 @@ gpm_backlight_notify_system_idle_changed (GpmBacklight *backlight, gboolean is_i
 		if (elapsed > 2*60) {
 			/* reset back to our default dimming */
 			backlight->priv->idle_dim_timeout =
-				g_settings_get_int (backlight->priv->settings,
-					   GPM_SETTINGS_IDLE_DIM_TIME);
+				g_settings_get_int (backlight->priv->settings_gsd,
+					   GSD_SETTINGS_IDLE_DIM_TIME);
 			g_debug ("resetting idle dim time to %is", backlight->priv->idle_dim_timeout);
 			gpm_idle_set_timeout_dim (backlight->priv->idle, backlight->priv->idle_dim_timeout);
 		}
@@ -561,8 +483,6 @@ gpm_backlight_idle_changed_cb (GpmIdle *idle, GpmIdleMode mode, GpmBacklight *ba
 	gboolean ret;
 	gboolean is_active;
 	GError *error = NULL;
-	gboolean on_battery;
-	GpmDpmsMode dpms_mode;
 
 	/* don't dim or undim the screen when the lid is closed */
 	if (gpm_button_is_lid_closed (backlight->priv->button))
@@ -610,23 +530,8 @@ gpm_backlight_idle_changed_cb (GpmIdle *idle, GpmIdleMode mode, GpmBacklight *ba
 		gpm_backlight_notify_system_idle_changed (backlight, TRUE);
 		gpm_backlight_brightness_evaluate_and_set (backlight, FALSE);
 
-		/* get the DPMS state we're supposed to use on the power state */
-		g_object_get (backlight->priv->client,
-			      "on-battery", &on_battery,
-			      NULL);
-		if (!on_battery)
-			dpms_mode = g_settings_get_enum (backlight->priv->settings, GPM_SETTINGS_DPMS_METHOD_AC);
-		else
-			dpms_mode = g_settings_get_enum (backlight->priv->settings, GPM_SETTINGS_DPMS_METHOD_BATT);
-
-		/* check if method is valid */
-		if (dpms_mode == GPM_DPMS_MODE_UNKNOWN || dpms_mode == GPM_DPMS_MODE_ON) {
-			g_warning ("BACKLIGHT method %s unknown. Using OFF.", gpm_dpms_mode_to_string (dpms_mode));
-			dpms_mode = GPM_DPMS_MODE_OFF;
-		}
-
 		/* turn backlight off */
-		ret = gpm_dpms_set_mode (backlight->priv->dpms, dpms_mode, &error);
+		ret = gpm_dpms_set_mode (backlight->priv->dpms, GPM_DPMS_MODE_OFF, &error);
 		if (!ret) {
 			g_warning ("failed to change DPMS: %s", error->message);
 			g_error_free (error);
@@ -636,30 +541,11 @@ gpm_backlight_idle_changed_cb (GpmIdle *idle, GpmIdleMode mode, GpmBacklight *ba
 
 /**
  * gpm_backlight_brightness_changed_cb:
- * @brightness: The GpmBrightness class instance
- * @percentage: The new percentage brightness
- * @brightness: This class instance
- *
- * This callback is called when the brightness value changes.
  **/
 static void
 gpm_backlight_brightness_changed_cb (GpmBrightness *brightness, guint percentage, GpmBacklight *backlight)
 {
-	/* save the new percentage */
-	backlight->priv->master_percentage = percentage;
-
-	/* we emit a signal for the brightness applet */
-	g_debug ("emitting brightness-changed : %i", percentage);
-	g_signal_emit (backlight, signals [BRIGHTNESS_CHANGED], 0, percentage);
-
-	/* and one for Dbus users */
-	g_dbus_connection_emit_signal (backlight->priv->bus_connection,
-			NULL,
-			GPM_DBUS_PATH_BACKLIGHT,
-			GPM_DBUS_INTERFACE_BACKLIGHT,
-			"BrightnessChanged",
-			g_variant_new ("(u)", percentage),
-			NULL);
+	gpm_backlight_brightness_changed (backlight, percentage);
 }
 
 /**
@@ -693,7 +579,7 @@ gpm_backlight_dbus_method_call (GDBusConnection *connection,
 				GVariant *parameters, GDBusMethodInvocation *invocation,
 				gpointer user_data)
 {
-	GError *error;
+	GError *error = NULL;
 	guint value;
 	gboolean ret;
 	GpmBacklight *backlight = GPM_BACKLIGHT (user_data);
@@ -800,6 +686,7 @@ gpm_backlight_finalize (GObject *object)
 	g_object_unref (backlight->priv->dpms);
 	g_object_unref (backlight->priv->control);
 	g_object_unref (backlight->priv->settings);
+	g_object_unref (backlight->priv->settings_gsd);
 	g_object_unref (backlight->priv->client);
 	g_object_unref (backlight->priv->button);
 	g_object_unref (backlight->priv->idle);
@@ -817,17 +704,7 @@ static void
 gpm_backlight_class_init (GpmBacklightClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
-	object_class->finalize	   = gpm_backlight_finalize;
-
-	signals [BRIGHTNESS_CHANGED] =
-		g_signal_new ("brightness-changed",
-			      G_TYPE_FROM_CLASS (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (GpmBacklightClass, brightness_changed),
-			      NULL, NULL,
-			      g_cclosure_marshal_VOID__UINT,
-			      G_TYPE_NONE, 1, G_TYPE_UINT);
-
+	object_class->finalize = gpm_backlight_finalize;
 	g_type_class_add_private (klass, sizeof (GpmBacklightPrivate));
 }
 
@@ -863,6 +740,8 @@ gpm_backlight_init (GpmBacklight *backlight)
 	/* watch for dim value changes */
 	backlight->priv->settings = g_settings_new (GPM_SETTINGS_SCHEMA);
 	g_signal_connect (backlight->priv->settings, "changed", G_CALLBACK (gpm_settings_key_changed_cb), backlight);
+	backlight->priv->settings_gsd = g_settings_new (GSD_SETTINGS_SCHEMA);
+	g_signal_connect (backlight->priv->settings_gsd, "changed", G_CALLBACK (gpm_settings_key_changed_cb), backlight);
 
 	/* set the main brightness, this is designed to be updated if the user changes the
 	 * brightness so we can undim to the 'correct' value */
@@ -880,15 +759,11 @@ gpm_backlight_init (GpmBacklight *backlight)
 
 	/* assumption */
 	backlight->priv->system_is_idle = FALSE;
-	backlight->priv->idle_dim_timeout = g_settings_get_int (backlight->priv->settings, GPM_SETTINGS_IDLE_DIM_TIME);
+	backlight->priv->idle_dim_timeout = g_settings_get_int (backlight->priv->settings_gsd, GSD_SETTINGS_IDLE_DIM_TIME);
 	gpm_idle_set_timeout_dim (backlight->priv->idle, backlight->priv->idle_dim_timeout);
 
 	/* use a visual widget */
-	backlight->priv->popup = gsd_media_keys_window_new ();
-	gsd_media_keys_window_set_action_custom (GSD_MEDIA_KEYS_WINDOW (backlight->priv->popup),
-						 "gpm-brightness-lcd",
-						 TRUE);
-	gtk_window_set_position (GTK_WINDOW (backlight->priv->popup), GTK_WIN_POS_NONE);
+	gpm_osd_dialog_init (&backlight->priv->popup, "display-brightness-symbolic");
 
 	/* DPMS mode poll class */
 	backlight->priv->dpms = gpm_dpms_new ();
