@@ -50,6 +50,7 @@
 #include "gpm-manager.h"
 #include "gpm-screensaver.h"
 #include "gpm-backlight.h"
+#include "gpm-kbd-backlight.h"
 #include "gpm-stock-icons.h"
 #include "gpm-tray-icon.h"
 #include "gpm-engine.h"
@@ -98,6 +99,7 @@ struct GpmManagerPrivate
 	GpmTrayIcon		*tray_icon;
 	GpmEngine		*engine;
 	GpmBacklight		*backlight;
+	GpmKbdBacklight		*kbd_backlight;
 	EggConsoleKit		*console;
 	guint32			 screensaver_ac_throttle_id;
 	guint32			 screensaver_dpms_throttle_id;
@@ -690,60 +692,6 @@ gpm_manager_action_hibernate (GpmManager *manager, const gchar *reason)
 	return TRUE;
 }
 
-/**
- * gpm_manager_logout:
- **/
-static gboolean
-gpm_manager_logout (GpmManager *manager)
-{
-	gboolean ret = FALSE;
-	GVariant *retval = NULL;
-	GError *error = NULL;
-	GDBusProxy *proxy = NULL;
-	GDBusConnection *connection;
-
-	/* connect to gnome-session */
-	connection = g_bus_get_sync (G_BUS_TYPE_SESSION, NULL, &error);
-	if (connection == NULL) {
-		g_warning ("Failed to connect to the session: %s", error->message);
-		g_error_free (error);
-		goto out;
-	}
-	proxy = g_dbus_proxy_new_sync (connection,
-			G_DBUS_PROXY_FLAGS_DO_NOT_LOAD_PROPERTIES |
-			G_DBUS_PROXY_FLAGS_DO_NOT_CONNECT_SIGNALS,
-			NULL,
-			"org.gnome.SessionManager",
-			"/org/gnome/SessionManager",
-			"org.gnome.SessionManager",
-			NULL, &error);
-	if (proxy == NULL) {
-		g_warning ("Failed to shutdown session: %s", error->message);
-		g_error_free (error);
-		goto out;
-	}
-
-	/* ask to shut it down */
-	retval = g_dbus_proxy_call_sync (proxy,
-					 "Shutdown",
-					 NULL, G_DBUS_CALL_FLAGS_NONE,
-					 -1, NULL, &error);
-	if (retval == NULL) {
-		g_debug ("Failed to shutdown session: %s", error->message);
-		g_error_free (error);
-		goto out;
-	}
-
-	/* success */
-	ret = TRUE;
-out:
-	if (retval != NULL)
-		g_variant_unref (retval);
-	if (proxy != NULL)
-		g_object_unref (proxy);
-	return ret;
-}
-
 /**
  * gpm_manager_perform_policy:
  * @manager: This class instance
@@ -778,9 +726,6 @@ gpm_manager_perform_policy (GpmManager  *manager, const gchar *policy_key, const
 		g_debug ("shutting down, reason: %s", reason);
 		gpm_control_shutdown (manager->priv->control, NULL);
 
-	} else if (policy == GPM_ACTION_POLICY_INTERACTIVE) {
-		g_debug ("logout, reason: %s", reason);
-		gpm_manager_logout (manager);
 	} else {
 		g_warning ("unknown action %i", policy);
 	}
@@ -907,17 +852,50 @@ gpm_manager_idle_changed_cb (GpmIdle *idle, GpmIdleMode mode, GpmManager *manage
 static void
 gpm_manager_lid_button_pressed (GpmManager *manager, gboolean pressed)
 {
+	const gchar *description;
+	const gchar *policy_key;
+	GpmActionPolicy policy;
+
 	if (pressed)
 		gpm_manager_play (manager, GPM_MANAGER_SOUND_LID_CLOSE, FALSE);
 	else
 		gpm_manager_play (manager, GPM_MANAGER_SOUND_LID_OPEN, FALSE);
 
+	/* we turn the lid dpms back on unconditionally */
 	if (pressed == FALSE) {
-		/* we turn the lid dpms back on unconditionally */
 		gpm_manager_unblank_screen (manager, NULL);
 		return;
 	}
 
+	/* we have different settings depending on AC state */
+	if (!manager->priv->on_battery) {
+		policy_key = GSD_SETTINGS_BUTTON_LID_AC;
+		description = "Lid closed on AC power";
+	} else {
+		policy_key = GSD_SETTINGS_BUTTON_LID_BATT;
+		description = "Lid closed on battery power";
+	}
+
+	/* check that on systems that would meld when the lid is closed
+	 * and not asleep we set a better policy option */
+	policy = g_settings_get_enum (manager->priv->settings_gsd,
+				      policy_key);
+	if (policy != GPM_ACTION_POLICY_SUSPEND &&
+	    policy != GPM_ACTION_POLICY_HIBERNATE) {
+#if UP_CHECK_VERSION(0,9,9)
+		if (up_client_get_lid_force_sleep (manager->priv->client)) {
+			g_warning ("to prevent damage, %s is now forced to 'suspend'",
+				   policy_key);
+			g_settings_set_enum (manager->priv->settings_gsd,
+					     policy_key,
+					     GPM_ACTION_POLICY_SUSPEND);
+		}
+#else
+		g_warning ("Laptop may melt if lid is closed. "
+			   "Update UPower and rebuild to find out!");
+#endif
+	}
+
 #if UP_CHECK_VERSION(0,9,8)
 	/* are we docked? */
 	if (up_client_get_is_docked (manager->priv->client)) {
@@ -926,16 +904,10 @@ gpm_manager_lid_button_pressed (GpmManager *manager, gboolean pressed)
 	}
 #endif
 
-	if (!manager->priv->on_battery) {
-		g_debug ("Performing AC policy");
-		gpm_manager_perform_policy (manager, GSD_SETTINGS_BUTTON_LID_AC,
-					    "Lid closed on AC power.");
-		return;
-	}
-
-	g_debug ("Performing battery policy");
-	gpm_manager_perform_policy (manager, GSD_SETTINGS_BUTTON_LID_BATT,
-				    "Lid closed on battery power.");
+	/* do action */
+	gpm_manager_perform_policy (manager,
+				    policy_key,
+				    description);
 }
 
 static void
@@ -2024,8 +1996,9 @@ gpm_manager_device_to_variant_blob (UpDevice *device)
 	GVariant *value;
 	GIcon *icon;
 	gchar *device_icon;
+	const gchar *object_path;
 
-	icon = gpm_upower_get_device_icon (device, FALSE);
+	icon = gpm_upower_get_device_icon (device, TRUE);
 	device_icon = g_icon_to_string (icon);
 	g_object_get (device,
 		      "kind", &kind,
@@ -2041,9 +2014,14 @@ gpm_manager_device_to_variant_blob (UpDevice *device)
 	else if (state == UP_DEVICE_STATE_CHARGING)
 		time_state = time_full;
 
+	/* get an object path, even for the composite device */
+	object_path = up_device_get_object_path (device);
+	if (object_path == NULL)
+		object_path = "/org/gnome/PowerManager";
+
 	/* format complex object */
 	value = g_variant_new ("(susdut)",
-			       up_device_get_object_path (device),
+			       object_path,
 			       kind,
 			       device_icon,
 			       percentage,
@@ -2196,6 +2174,12 @@ gpm_manager_bus_acquired_cb (GDBusConnection *connection,
 	if (manager->priv->backlight != NULL) {
 		gpm_backlight_register_dbus (manager->priv->backlight, connection);
 	}
+
+	if (manager->priv->kbd_backlight != NULL) {
+		gpm_kbd_backlight_register_dbus (manager->priv->kbd_backlight,
+						 connection,
+						 NULL);
+	}
 }
 
 /**
@@ -2281,6 +2265,9 @@ gpm_manager_init (GpmManager *manager)
 	/* try an start an interactive service */
 	manager->priv->backlight = gpm_backlight_new ();
 
+	/* try and start an interactive service */
+	manager->priv->kbd_backlight = gpm_kbd_backlight_new ();
+
 	manager->priv->idle = gpm_idle_new ();
 	g_signal_connect (manager->priv->idle, "idle-changed",
 			  G_CALLBACK (gpm_manager_idle_changed_cb), manager);
@@ -2386,6 +2373,7 @@ gpm_manager_finalize (GObject *object)
 	g_object_unref (manager->priv->control);
 	g_object_unref (manager->priv->button);
 	g_object_unref (manager->priv->backlight);
+	g_object_unref (manager->priv->kbd_backlight);
 	g_object_unref (manager->priv->console);
 	g_object_unref (manager->priv->client);
 	g_object_unref (manager->priv->status_icon);
